Package: semtree
Type: Package
Title: Recursive Partitioning for Structural Equation Models
Authors@R: c(person("Andreas M. Brandmaier", email="andy@brandmaier.de", role=c("aut","cre")), person("John J. Prindle", email="jprindle@usc.edu",role=c("aut")),person("Manuel Arnold", email="arnoldmz@hu-berlin.de",role=c("aut")),person("Caspar J. Van Lissa", email="C.J.vanLissa@uu.nl",role=c("aut")), person("Moritz John",role="ctb"))
Author: Andreas M. Brandmaier [aut, cre],
  John J. Prindle [aut],
  Manuel Arnold [aut],
  Caspar J. Van Lissa [aut],
  Moritz John [ctb]
Maintainer: Andreas M. Brandmaier <andy@brandmaier.de>
Depends: R (>= 2.10), OpenMx (>= 2.6.9),
Imports: rpart, rpart.plot (>= 3.0.6), lavaan, cluster, ggplot2, tidyr,
        dplyr, methods, strucchange, sandwich, zoo, crayon, clisymbols,
        future.apply, data.table, expm, gridBase
Suggests: knitr, rmarkdown, viridis, MASS, psych, psychTools, testthat,
        future, ctsemOMX
Description: SEM Trees and SEM Forests -- an extension of model-based decision
    trees and forests to Structural Equation Models (SEM). SEM trees hierarchically
    split empirical data into homogeneous groups each sharing similar data patterns
    with respect to a SEM by recursively selecting optimal predictors of these
    differences. SEM forests are an extension of SEM trees. They are ensembles of
    SEM trees each built on a random sample of the original data. By aggregating
    over a forest, we obtain measures of variable importance that are more robust
    than measures from single trees. A description of the method was published by
    Brandmaier, von Oertzen, McArdle, & Lindenberger (2013) <doi:10.1037/a0030001> 
    and Arnold, Voelkle, & Brandmaier (2020) <doi:10.3389/fpsyg.2020.564403>.
License: GPL-3
Encoding: UTF-8
LazyLoad: yes
Version: 0.9.23
Date: 2025-11-26
RoxygenNote: 7.3.3
VignetteBuilder: knitr
BugReports: https://github.com/brandmaier/semtree/issues
URL: https://github.com/brandmaier/semtree
Language: en-US
NeedsCompilation: no
Packaged: 2025-11-26 16:01:24 UTC; andreas.brandmaier
Repository: CRAN
Date/Publication: 2025-11-26 16:40:02 UTC
Built: R 4.6.0; ; 2026-04-30 03:35:41 UTC; unix
