# Generated by roxygen2: do not edit by hand

S3method("[",semforest)
S3method("[",semtree)
S3method(evaluate,semforest)
S3method(logLik,semtree)
S3method(merge,semforest)
S3method(merge,semforest.varimp)
S3method(nobs,semtree)
S3method(partialDependence,semforest)
S3method(partialDependence,semforest_stripped)
S3method(plot,boruta)
S3method(plot,diversityMatrix)
S3method(plot,partialDependence)
S3method(plot,semforest.proximity)
S3method(plot,semforest.varimp)
S3method(plot,semtree)
S3method(predict,semforest)
S3method(predict,semforest_stripped)
S3method(predict,semtree)
S3method(print,semforest)
S3method(print,semforest.control)
S3method(print,semforest.varimp)
S3method(print,semforest_stripped)
S3method(print,semtree)
S3method(print,semtree.control)
S3method(print,summary.semtree)
S3method(proximity,semforest)
S3method(proximity,semforest_node_id)
S3method(proximity,semforest_stripped)
S3method(prune,semforest)
S3method(prune,semtree)
S3method(strip,semforest)
S3method(strip,semtree)
S3method(summary,semforest)
S3method(summary,semtree)
S3method(toLatex,semtree)
export(biodiversity)
export(boruta)
export(diversityMatrix)
export(evaluateTree)
export(fitSubmodels)
export(getDepth)
export(getLeafs)
export(getNodeById)
export(getParDiffForest)
export(getParDiffTree)
export(getTerminalNodes)
export(hellinger)
export(isLeaf)
export(kl)
export(modelEstimates)
export(outliers)
export(parameters)
export(partialDependence)
export(partialDependence_data)
export(partialDependence_growth)
export(plotParDiffForest)
export(plotParDiffTree)
export(plotTreeStructure)
export(proximity)
export(prune)
export(se)
export(semforest)
export(semforest.control)
export(semforest_control)
export(semforest_score_control)
export(semtree)
export(semtree.constraints)
export(semtree.control)
export(semtree_control)
export(strip)
export(subforest)
export(subtree)
export(toTable)
export(varimp)
export(varimpConvergencePlot)
import(OpenMx)
import(data.table)
import(rpart)
importFrom(data.table,data.table)
importFrom(dplyr,"%>%")
importFrom(grDevices,heat.colors)
importFrom(graphics,barplot)
importFrom(graphics,hist)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,pairs)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,strwidth)
importFrom(graphics,text)
importFrom(lavaan,lavScores)
importFrom(lavaan,nobs)
importFrom(lavaan,vcov)
importFrom(methods,hasArg)
importFrom(methods,is)
importFrom(parallel,clusterMap)
importFrom(parallel,parLapply)
importFrom(sandwich,bread)
importFrom(stats,as.dist)
importFrom(stats,as.formula)
importFrom(stats,cmdscale)
importFrom(stats,coef)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,dist)
importFrom(stats,logLik)
importFrom(stats,median)
importFrom(stats,pchisq)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,rnorm)
importFrom(stats,runif)
importFrom(stats,var)
importFrom(strucchange,catL2BB)
importFrom(strucchange,maxBB)
importFrom(strucchange,meanL2BB)
importFrom(strucchange,ordL2BB)
importFrom(strucchange,ordwmax)
importFrom(strucchange,root.matrix)
importFrom(strucchange,sctest)
importFrom(strucchange,supLM)
importFrom(utils,data)
importFrom(utils,flush.console)
importFrom(utils,getS3method)
importFrom(utils,sessionInfo)
importFrom(utils,setTxtProgressBar)
importFrom(utils,str)
importFrom(utils,toLatex)
importFrom(zoo,zoo)
